cis_config: /root/cis_interface/cis_interface/cis_interface/regex/regex_win32.h Source File

cis_config

regex_win32.h
1
2 #ifndef REGEX_WIN32_H_
3 #define REGEX_WIN32_H_
4
5 #ifdef __cplusplus
6 #define EXTERNC extern "C"
7 #else
8 #define EXTERNC
9 #endif
10
11 EXTERNC int count_matches(const char *regex_text, const char *to_match);
12 EXTERNC int find_matches(const char *regex_text, const char *to_match,
13 size_t **sind, size_t **eind);
14 EXTERNC int find_match(const char *regex_text, const char *to_match,
15 size_t *sind, size_t *eind);
16 EXTERNC int regex_replace_nosub(char *buf, const size_t len_buf,
17 const char *re, const char *rp,
18 const size_t nreplace);
19 EXTERNC int get_subrefs(const char *buf, size_t **refs);
20 EXTERNC int regex_replace_sub(char *buf, const size_t len_buf,
21 const char *re, const char *rp,
22 const size_t nreplace);
23
24 #undef EXTERNC
25 #endif /*REGEX_WIN32_H_*/